Publications
============

Publications are the central component of Django-Vitae since publications are the key 
element of CVs. Django-Vitae includes four types of publications: :ref:`books 
<topics-pubs-books>`, :ref:`articles <topics-pubs-articles>`, :ref:`chapters 
<topics-pubs-chapters>`, and :ref:`reports <topics-pubs-reports>`. These models share some :ref:`common features <topics-pubs-common-features>`. 

.. toctree::
   :name: pubstoc
   :maxdepth: 2
   :caption: Contents:

   common 
   articles
   books
   chapters
   reports